-------------------------------------------
--- Target detection and artillery fire ---
-------------------------------------------
--
-- Name: DET-500 - Handle Detected Event - Govern Artillery Demo
-- Author: FlightControl
-- Date Created: 13 Feb 2017
--
-- A Set of friendly units detect a group of enemy units and call in artillery strikes.
-- The artillery units are AI controlled and will fire a missile or shell at the target.
-- If there is a warehouse nearby to resupply the artillery, strikes will continue until the artillery unit is destroyed or the mission ends.
--
-- Create and place artillery units with mission editor
-- Create a HQ vehicle
-- Create a warehouse near the artillery units to resupply ammo
-- Confirm artillery units are within range of battlefield

RecceSetGroupB = SET_GROUP:New():FilterCoalitions( "red" ):FilterPrefixes( "Red" ):FilterStart()
ArtillerySetGroupB = SET_GROUP:New():FilterCoalitions( "red" ):FilterPrefixes( "Red Arty" ):FilterStart()

HQ = GROUP:FindByName( "Red Arty HQ" )

CC = COMMANDCENTER:New( HQ, "Red Arty HQ" )

RecceDetection = DETECTION_UNITS:New( RecceSetGroupB )
RecceDetection:SetRefreshTimeInterval( 35 )

RecceDetection:Start()

--- OnAfter Transition Handler for Event Detect.
-- @param Functional.Detection#DETECTION_UNITS self
-- @param #string From The From State string.
-- @param #string Event The Event string.
-- @param #string To The To State string.
-----------------------------------------------------------------------------
--uncomment this if you want ingame reports
-- function RecceDetection:OnAfterDetect(From,Event,To)

  -- local DetectionReport = RecceDetection:DetectedReportDetailed()

  -- CC:GetPositionable():MessageToAll( DetectionReport, 15, "" )
-- end
-----------------------------------------------------------------------------

local ArtilleryTime = {}
local ArtilleryAim = 205

--- OnAfter Transition Handler for Event Detect.
-- @param Functional.Detection#DETECTION_UNITS self
-- @param #string From The From State string.
-- @param #string Event The Event string.
-- @param #string To The To State string.
-- @param Wrapper.Unit#UNIT DetectedUnits

function RecceDetection:OnAfterDetected( From, Event, To, DetectedUnits )
  self:E( { From, Event, To, DetectedUnits } )

  for DetectedUnitID, DetectedUnit in pairs( DetectedUnits ) do
    local DetectedUnit = DetectedUnit -- Wrapper.Unit#UNIT
    local Artillery = ArtillerySetGroupB:GetRandom() -- Wrapper.Group#GROUP
    
    if ArtilleryTime[Artillery] and ArtilleryTime[Artillery] <= timer.getTime() - ArtilleryAim then
      ArtilleryTime[Artillery] = nil
    end

-- @param DCS#Vec2 Vec2 The point to fire at.
-- @param DCS#Distance Radius The radius of the zone to deploy the fire at.
-- @param #number AmmoCount (optional) Quantity of ammunition to expand (omit to fire until ammunition is depleted).
-- @param #number WeaponType (optional) Enum for weapon type ID. This value is only required if you want the group firing to use a specific weapon, for instance using the task on a ship to force it to fire guided missiles at targets within cannon range. See http://wiki.hoggit.us/view/DCS_enum_weapon_flag
-- function CONTROLLABLE:TaskFireAtPoint( Vec2, Radius, AmmoCount, WeaponType )

    if not ArtilleryTime[Artillery] then
      local Task = Artillery:TaskFireAtPoint( DetectedUnit:GetVec2(), 250, 4 ) -- Fire 4 projectiles per artillery group at the target point.
      Artillery:SetTask( Task, 0.5 )
      ArtilleryTime[Artillery] = timer.getTime()
    end
    
  end
end



